@@ -1,7 +1,7 @@
 package Terminal::Control;
 # This package provides the basis for improving and studying Terminal Window
 # control. Essentially, the Perl header 'sys/ioctl.ph', the SHELL command stty
-# and ASCII escape sequences are used.
+# and ANSI escape sequences are used.
 
 # Load the basic Perl pragmas.
 use 5.030000;
@@ -16,7 +16,7 @@ use bytes;
 use Try::Catch;
 
 # Set the package version. 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -62,9 +62,9 @@ BEGIN {
     # Try to load Time::HiRes
     eval {require Time::HiRes}
     or die "Could not load module Time::HiRes\n";
-    import Time::HiRes qw(ualarm);
+    eval {import Time::HiRes qw(ualarm)};
     # Try to load sys/ioctl.ph.
-    $is_eval = ((eval "require 'sys/ioctl1.ph'") ? 1 : 0);
+    $is_eval = ((eval "require 'sys/ioctl.ph'") ? 1 : 0);
     if ($is_eval ne 1) {
         # Print message into the terminal window.
         print "sys/ioctl.ph is missing\n";
@@ -440,13 +440,15 @@ Terminal::Control - Perl extension with methods for the control of the terminal
 
 =head1 ABSTRACT
 
-The module contains, among others, two methods for clearing and
-resetting the terminal window. This is a standard task when
-scripts has to be executed in the terminal window. The realted 
-Shell commands are slow in comparison to the presented module
-commands. This is achieved by using ANSI escape sequences. XTERM
-control sequences can be used to query screen and window data.
-The terminal or window size is available via the system call ioctl.
+The module is intended for B<Linux> as well as B<Unix> or B<Unix-like>
+operating systems in general. These operating systems meet the requirements
+for using the module and its methods. The module contains, among others, two
+methods for clearing and resetting the terminal window. This is a standard
+task when scripts has to be executed in the terminal window. The related Shell
+commands are slow in comparison to the implemented methods in this module. This
+is achieved by using ANSI escape sequences. In addition XTERM control sequences
+can be used to query screen and window size. The terminal or window size is in
+general available via the system call ioctl.
 
 =head1 SYNOPSIS
 
@@ -470,13 +472,13 @@ The terminal or window size is available via the system call ioctl.
   ($xpix, $ypix) = pixels();
   printf ("%s\n%s\n", $xpix, $ypix);
 
-  # Get the cursor position using ANSI escape sequences.
+  # Get the cursor position in chars (not in pixels) using ANSI escape sequences.
   my ($row, $col) = get_cursor_position();
-  printf ("%s\n%s\n", $rows, $cols);
+  printf ("%s\n%s\n", $row, $col);
 
   # Set the cursor position in chars (not in pixels) using ANSI escape sequences.
-  my $rows = 20; 
-  my $cols = 80; 
+  my $row = 20; 
+  my $col = 80; 
   # $row and $col are required and must be set by the user.
   set_cursor_position($row, $col);
 
@@ -541,10 +543,10 @@ Exemplary comparison of time of execution:
   reset_screen()   =>  0.000076 Seconds =    0,076 Milliseconds = 76 Microseconds
 
 Using C<reset> on the command line and the Perl command C<system("reset")> have nearly
-the same result. Detailed comparison is outstanding. This one example already shows a
-significant advantage of the new routine.
+the same result in time of execution. Detailed comparison is outstanding. This one example
+already shows a significant advantage of the new routine.
 
-=head1 System Compatibility
+=head1 SYSTEM COMPATIBILITY
 
 Three things must be fulfilled in order to use the full functionality of the
 module.
@@ -570,11 +572,31 @@ to create a C<sys/ioctl.ph>. This is necessary manually via the C<h2ph> command.
 To prevent tests within CPAN from failing due to a missing C<sys/ioctl.ph>, a
 fallback solution based on the Shell command C<stty> is implemented.   
 
-=head1 ANSI Escape Sequences Versus XTERM Control Sequences
+=head1 ANSI ESCAPE SEQUENCES VERSUS XTERM CONTROL SEQUENCES
 
 ANSI escape sequences are widely known. Less well known are the so-called XTERM
 control sequences.
 
+=head2 ANSI escape sequences
+
+Escape sequences used by the module:
+
+  CSI n ; m H  =>  CUP      =>  Cursor Position       =>  Moves the cursor to row n, column m 
+  CSI 6n       =>  DSR      =>  Device Status Report  =>  Reports the cursor position (CPR)
+                                                          by transmitting ESC[n;mR,
+                                                          where n is the row and m is the column
+  CSI ? 25 h   =>  DECTCEM  =>  Shows the cursor
+  CSI ? 25 l   =>  DECTCEM  =>  Hides the cursor 
+
+=head2 XTERM control sequences
+
+Escape sequences used by the module:
+
+  CSI 1 4 t  =>  report window size in pixels
+  CSI 1 5 t  =>  report screen size in pixels
+  CSI 1 8 t  =>  report window size in chars
+  CSI 1 9 t  =>  report screen size in chars
+
 =head1 DESCRIPTION
 
 =head2 Implemented Methods
@@ -677,7 +699,7 @@ position in the terminal window.
 C<echo_on()> and C<echo_off()> turnes echo of commands on or off.C<cursor_on()> and
 C<cursor_off> shows or hides the cursor.
 
-=head1 Programmable background
+=head1 PROGRAMMABLE BACKGROUND
 
 The methods C<clear_screen()> and C<reset_screen()> are using ANSI escape sequences.
 Doing this no other Perl commands are needed to clear and reset a screen. 
